/**
 * The iterator used by `Sequence` to iterate over the underlying data.
 */
interface SequenceIterator<T> {
    hasNext(): boolean;
    next(): T;
}
export default SequenceIterator;
export declare class IterableIterator<T> implements SequenceIterator<T> {
    private readonly iterator;
    private done;
    private nextItem;
    constructor(iterable: Iterable<T>);
    hasNext(): boolean;
    next(): T;
    private processNext();
}
export declare class GeneratorIterator<T> implements SequenceIterator<T> {
    private readonly nextFunction;
    private done;
    private nextItem;
    constructor(nextFunction: () => T | null | undefined);
    hasNext(): boolean;
    next(): T;
    private processNext();
}
export declare class GeneratorSeedIterator<T> implements SequenceIterator<T> {
    private readonly seed;
    private readonly nextFunction;
    private nextItem;
    private prevItem;
    private done;
    constructor(seed: T, nextFunction: (value: T) => T | null | undefined);
    hasNext(): boolean;
    next(): T;
    private processNext();
}
