Object.defineProperty(exports, "__esModule", { value: true });
var IterableIterator = /** @class */ (function () {
    function IterableIterator(iterable) {
        this.done = false;
        this.iterator = iterable[Symbol.iterator]();
    }
    IterableIterator.prototype.hasNext = function () {
        this.processNext();
        return !this.done;
    };
    IterableIterator.prototype.next = function () {
        this.processNext();
        var result = this.nextItem;
        this.nextItem = undefined;
        return result;
    };
    IterableIterator.prototype.processNext = function () {
        if (this.done || this.nextItem !== undefined) {
            return;
        }
        var _a = this.iterator.next(), done = _a.done, value = _a.value;
        if (done) {
            this.done = done;
            this.nextItem = undefined;
        }
        else {
            this.nextItem = value;
        }
    };
    return IterableIterator;
}());
exports.IterableIterator = IterableIterator;
var GeneratorIterator = /** @class */ (function () {
    function GeneratorIterator(nextFunction) {
        this.nextFunction = nextFunction;
        this.done = false;
    }
    GeneratorIterator.prototype.hasNext = function () {
        this.processNext();
        return !this.done;
    };
    GeneratorIterator.prototype.next = function () {
        this.processNext();
        var result = this.nextItem;
        this.nextItem = undefined;
        return result;
    };
    GeneratorIterator.prototype.processNext = function () {
        if (this.done || this.nextItem !== undefined) {
            return;
        }
        var result = this.nextFunction();
        if (result == null) {
            this.done = true;
        }
        else {
            this.nextItem = result;
        }
    };
    return GeneratorIterator;
}());
exports.GeneratorIterator = GeneratorIterator;
var GeneratorSeedIterator = /** @class */ (function () {
    function GeneratorSeedIterator(seed, nextFunction) {
        this.seed = seed;
        this.nextFunction = nextFunction;
        this.nextItem = this.seed;
        this.done = false;
    }
    GeneratorSeedIterator.prototype.hasNext = function () {
        this.processNext();
        return !this.done;
    };
    GeneratorSeedIterator.prototype.next = function () {
        this.processNext();
        var result = this.nextItem;
        this.prevItem = result;
        this.nextItem = undefined;
        return result;
    };
    GeneratorSeedIterator.prototype.processNext = function () {
        if (this.done || this.nextItem !== undefined) {
            return;
        }
        var result = this.nextFunction(this.prevItem);
        if (result == null) {
            this.done = true;
        }
        else {
            this.prevItem = this.nextItem;
            this.nextItem = result;
        }
    };
    return GeneratorSeedIterator;
}());
exports.GeneratorSeedIterator = GeneratorSeedIterator;
//# sourceMappingURL=SequenceIterator.js.map