Object.defineProperty(exports, "__esModule", { value: true });
var Sequence_1 = require("./Sequence");
var DropWhileIterator = /** @class */ (function () {
    function DropWhileIterator(iterator, predicate) {
        this.iterator = iterator;
        this.predicate = predicate;
        this.done = false;
        this.dropping = true;
    }
    DropWhileIterator.prototype.hasNext = function () {
        this.processNext();
        return !this.done;
    };
    DropWhileIterator.prototype.next = function () {
        this.processNext();
        var result = this.nextItem;
        this.nextItem = undefined;
        return result;
    };
    DropWhileIterator.prototype.processNext = function () {
        if (this.done || this.nextItem !== undefined) {
            return;
        }
        while (this.iterator.hasNext()) {
            var item = this.iterator.next();
            if (!this.dropping) {
                this.nextItem = item;
                return;
            }
            var result = this.predicate(item);
            if (!result) {
                this.dropping = false;
                this.nextItem = item;
                return;
            }
        }
        this.done = true;
    };
    return DropWhileIterator;
}());
var DropWhile = /** @class */ (function () {
    function DropWhile() {
    }
    /**
     * Drops all elements of the sequence as long as the given `predicate` evaluates to true.
     *
     * @param {(item: T) => boolean} predicate
     * @returns {Sequence<T>}
     */
    DropWhile.prototype.dropWhile = function (predicate) {
        return Sequence_1.createSequence(new DropWhileIterator(this.iterator, predicate));
    };
    return DropWhile;
}());
exports.DropWhile = DropWhile;
//# sourceMappingURL=dropWhile.js.map